:mod:`cybox.objects.win_memory_page_region_object` module
=========================================================

.. automodule:: cybox.objects.win_memory_page_region_object
    :members:
    :undoc-members:
    :show-inheritance:
